@@ -14,8 +14,10 @@ class InvokationType(StrEnum):
     INCOMING_MESSAGE_CALLBACK = "incoming_message_callback"
     SINGLE_QUALITY_TEST_CALLBACK = "single_quality_test_callback"
     SMART_TAGGING_CALLBACK = "smart_tagging_callback"
-
-
+    QUALITY_TESTS_FOR_UPDATED_AI_COMPONENT = "quality_tests_for_updated_ai_component"
+    FIX_BUGGED_AI_AGENTS_CALLS_IN_CHATS = "fix_bugged_ai_agents_calls_in_chats"
+    DOUBLE_CHECKER_FOR_INCOMING_MESSAGES_ANSWER = "double_checker_for_incoming_messages_answer"
+    DOUBLE_CHECKER_FOR_INCOMING_MESSAGES_ANSWER_CALLBACK = "double_checker_for_incoming_messages_answer_callback"
 class LambdaAiEvent(BaseModel):
     type: InvokationType
     data: dict
