@@ -7,6 +7,7 @@ from .system_content import MetaSystemContent
 from .interactive_content import MetaInteractiveContent
 from .button_content import MetaButtonContent
 from .order_content import MetaOrderContent
+from .reaction_content import MetaReactionContent
 
-MetaContent = Union[MetaTextContent, MetaImageContent, MetaAudioContent, MetaVideoContent, MetaDocumentContent, MetaStickerContent, MetaLocationContent, MetaContactContent, MetaSystemContent, MetaInteractiveContent, MetaButtonContent, MetaOrderContent]
+MetaContent = Union[MetaTextContent, MetaImageContent, MetaAudioContent, MetaVideoContent, MetaDocumentContent, MetaStickerContent, MetaLocationContent, MetaContactContent, MetaSystemContent, MetaInteractiveContent, MetaButtonContent, MetaOrderContent, MetaReactionContent]
 MetaMediaContent = Union[MetaImageContent, MetaAudioContent, MetaVideoContent, MetaDocumentContent, MetaStickerContent]
\ No newline at end of file
